==> hive-exec-2.3.7-sources.jar: org/apache/hadoop/hive/ql/exec/vector/expressions/VectorUDFUnixTimeStampDate.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.vector.expressions;

import org.apache.hadoop.hive.serde2.io.DateWritable;

/**
 * Return Unix Timestamp.
 * Extends {@link VectorUDFTimestampFieldDate}
 */
public final class VectorUDFUnixTimeStampDate extends VectorUDFTimestampFieldDate {

  private static final long serialVersionUID = 1L;

  private DateWritable dateWritable;

  @Override
  protected long getDateField(long days) {
    dateWritable.set((int) days);
    return dateWritable.getTimeInSeconds();
  }

  public VectorUDFUnixTimeStampDate(int colNum, int outputColumn) {
    /* not a real field */
    super(-1, colNum, outputColumn);
    dateWritable = new DateWritable();
  }

  public VectorUDFUnixTimeStampDate() {
    super();
  }

}

==> hive-exec-3.0.0-sources.jar: org/apache/hadoop/hive/ql/exec/vector/expressions/VectorUDFUnixTimeStampDate.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.ql.exec.vector.expressions;

import org.apache.hadoop.hive.serde2.io.DateWritable;

/**
 * Return Unix Timestamp.
 * Extends {@link VectorUDFTimestampFieldDate}
 */
public final class VectorUDFUnixTimeStampDate extends VectorUDFTimestampFieldDate {

  private static final long serialVersionUID = 1L;

  private DateWritable dateWritable;

  @Override
  protected long getDateField(long days) {
    dateWritable.set((int) days);
    return dateWritable.getTimeInSeconds();
  }

  public VectorUDFUnixTimeStampDate(int colNum, int outputColumnNum) {
    /* not a real field */
    super(-1, colNum, outputColumnNum);
    dateWritable = new DateWritable();
  }

  public VectorUDFUnixTimeStampDate() {
    super();
  }

}
